*******************
Authors and Credits
*******************

Specutils Maintainers
=====================

 * Wolfgang Kerzendorf
 * Adam Ginsburg

Contributors
============

 * Adrian Price-Whelan
 * Benjamin Alan Weaver
 * Brigitta Sipocz
 * Christoph Deil
 * David Syphers
 * Demitri Muna
 * Dinos Kousidis
 * Erik Bray
 * Erik Tollerud
 * Gustavo Braganca
 * Hans Moritz Günther
 * Jeremy A. Lusk
 * Joe Philip Ninan
 * Jonathan Foster
 * Kyle Barbary
 * Leo Singer
 * Marten van Kerkwijk
 * Matthew Craig
 * Michael Droettboom
 * Shailesh Ahuja
 * Thomas Robitaille
 * Andy Casey
 * Larry Bradley
